==> qore-0.9.12.tar.bz2: qore-0.9.12/docs/modules/DataProvider/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore DataProvider Module Reference", "index.html", [
    [ "DataProvider Module", "index.html", [
      [ "Introduction to the DataProvider Module", "index.html#dataproviderintro", [
        [ "Data Provider Modules", "index.html#dataprovider_modules", [
          [ "Data Provider Dynamic Discovery", "index.html#dataprovider_dynamic_discovery", null ],
          [ "Data Provider Type Dynamic Discovery", "index.html#dataprovider_type_dynamic_discovery", null ]
        ] ]
      ] ],
      [ "Data Provider Pipelines", "index.html#dataprovider_pipelines", null ],
      [ "Data Provider Pipeline Bulk Processing", "index.html#dataprovider_pipeline_bulk_processing", null ],
      [ "Release Notes", "index.html#dataprovider_relnotes", [
        [ "DataProvider v1.0.5", "index.html#dataprovider_v1_0_5", null ],
        [ "DataProvider v1.0.4", "index.html#dataprovider_v1_0_4", null ],
        [ "DataProvider v1.0.3", "index.html#dataprovider_v1_0_3", null ],
        [ "DataProvider v1.0.2", "index.html#dataprovider_v1_0_2", null ],
        [ "DataProvider v1.0.1", "index.html#dataprovider_v1_0_1", null ],
        [ "DataProvider v1.0", "index.html#dataprovider_v1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"class_data_provider_1_1_data_provider_pipeline.html#ade8ea00539f62ae1894e522859585e6d",
"class_data_provider_1_1_qore_int_data_type_base.html#aed1f02997d65867401b80e0fe04dcd65",
"group__date__and__time__functions.html#ga098fc81e482c4ad4eeef3446c98f9b38",
"group__error__constants.html#gaf66f910d36169c48110fddedcea53c48",
"group__math__functions.html#ga8dc307313dd965ae431e7b01d262f3a2",
"group__parse__options.html#ga094a2d1f503a2b1e9abbe11b0d47cc6e",
"group__string__type__constants.html#ga0ab460f39fd71e687c2eb26352da2059",
"group__zsocket__poll__constants.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-0.9.13.tar.bz2: qore-0.9.13/docs/modules/DataProvider/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore DataProvider Module Reference", "index.html", [
    [ "DataProvider Module", "index.html", [
      [ "Introduction to the DataProvider Module", "index.html#dataproviderintro", [
        [ "Data Provider Modules", "index.html#dataprovider_modules", [
          [ "Data Provider Dynamic Discovery", "index.html#dataprovider_dynamic_discovery", null ],
          [ "Data Provider Type Dynamic Discovery", "index.html#dataprovider_type_dynamic_discovery", null ]
        ] ]
      ] ],
      [ "Data Provider Pipelines", "index.html#dataprovider_pipelines", null ],
      [ "Data Provider Pipeline Bulk Processing", "index.html#dataprovider_pipeline_bulk_processing", null ],
      [ "Release Notes", "index.html#dataprovider_relnotes", [
        [ "DataProvider v1.0.5", "index.html#dataprovider_v1_0_5", null ],
        [ "DataProvider v1.0.4", "index.html#dataprovider_v1_0_4", null ],
        [ "DataProvider v1.0.3", "index.html#dataprovider_v1_0_3", null ],
        [ "DataProvider v1.0.2", "index.html#dataprovider_v1_0_2", null ],
        [ "DataProvider v1.0.1", "index.html#dataprovider_v1_0_1", null ],
        [ "DataProvider v1.0", "index.html#dataprovider_v1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"class_data_provider_1_1_data_provider_pipeline.html#ade8ea00539f62ae1894e522859585e6d",
"class_data_provider_1_1_qore_int_data_type_base.html#aed1f02997d65867401b80e0fe04dcd65",
"group__date__and__time__functions.html#ga098fc81e482c4ad4eeef3446c98f9b38",
"group__error__constants.html#gadbd06a622538d79f0ea06bc22594e01a",
"group__library__functions.html#gae6dd9a1ccae25a097d61cf0575161075",
"group__misc__functions.html#gae83a1a257c36f235bfaaba52583553ac",
"group__signal__constants.html#gafd6b196e097d02519f301fe2ac2394e5",
"group__threading__functions.html#gac1735e87940d93e2614485c050217ac5"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
